[Libguestfs] [p2v PATCH 3/3] Ignore 'openstack' driver

Pino Toscano ptoscano at redhat.com
Mon Mar 16 13:55:11 UTC 2020


The 'openstack' output mode requires few options, and virt-p2v does not
have the GUI bits for specifying them.

Similar to commit 9b009aa4a3898648fe68301d1c5ed774a0bf2e38 (for
rhv-upload).
---
 ssh.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/ssh.c b/ssh.c
index 9dd2d8a..ce0caaa 100644
--- a/ssh.c
+++ b/ssh.c
@@ -1018,10 +1018,11 @@ static void
 add_output_driver (const char *name, size_t len)
 {
   /* Ignore the 'vdsm' driver, since that should only be used by VDSM.
    * Ignore the 'rhv-upload' driver, since we do not support passing all the
    * options for it.
    */
   if ((len != 4 || memcmp (name, "vdsm", 4) != 0) &&
+      (len != 9 || memcmp (name, "openstack", 9) != 0) &&
       (len != 10 || memcmp (name, "rhv-upload", 10) != 0))
     add_option ("output", &output_drivers, name, len);
 }
@@ -1018,10 +1018,11 @@ static void
 {
   /* Ignore the 'vdsm' driver, since that should only be used by VDSM.
-   * Ignore the 'rhv-upload' driver, since we do not support passing all the
-   * options for it.
+   * Ignore the 'openstack' and 'rhv-upload' drivers, since we do not
+   * support passing all the options for them.
    */
   if ((len != 4 || memcmp (name, "vdsm", 4) != 0) &&
-- 
2.24.1




More information about the Libguestfs mailing list